@@ -38,7 +38,7 @@ use Test::Builder    ();
 
 use vars qw{$VERSION @ISA @EXPORT};
 BEGIN {
-	$VERSION = '1.01';
+	$VERSION = '1.02';
 	require Exporter;
 	@ISA     = qw( Exporter );
 	@EXPORT  = qw( script_compiles_ok );
@@ -85,11 +85,13 @@ sub script_compiles_ok {
 	my $unix   = shift;
 	my $name   = shift || "Script $unix compiles";
 	my $path   = path( $unix );
-	my $cmd    = [ $^X, '-c', $path ];
+	my $cmd    = [ $^X, '-c', '-Mblib', $path ];
 	my $stderr = '';
 	my $rv     = IPC::Run3::run3( $cmd, \undef, \undef, \$stderr );
 	my $ok     = !! ( $rv and $stderr =~ /syntax OK\s+$/si );
 	$Test->ok( $ok, $name );
+	# Add this once I can make the tests work ok
+	# $Test->diag( $stderr ) unless $ok;
 	return $ok;
 }
 
